==> huaweicloudsdkcce-3.1.134-py2.py3-none-any.whl: huaweicloudsdkcce/v3/model/show_autopilot_chart_values_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowAutopilotChartValuesResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'values': 'ChartValueValues'
    }

    attribute_map = {
        'values': 'values'
    }

    def __init__(self, values=None):
        """ShowAutopilotChartValuesResponse

        The model defined in huaweicloud sdk

        :param values: 
        :type values: :class:`huaweicloudsdkcce.v3.ChartValueValues`
        """
        
        super(ShowAutopilotChartValuesResponse, self).__init__()

        self._values = None
        self.discriminator = None

        if values is not None:
            self.values = values

    @property
    def values(self):
        """Gets the values of this ShowAutopilotChartValuesResponse.

        :return: The values of this ShowAutopilotChartValuesResponse.
        :rtype: :class:`huaweicloudsdkcce.v3.ChartValueValues`
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this ShowAutopilotChartValuesResponse.

        :param values: The values of this ShowAutopilotChartValuesResponse.
        :type values: :class:`huaweicloudsdkcce.v3.ChartValueValues`
        """
        self._values = values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowAutopilotChartValuesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcce-3.1.151-py2.py3-none-any.whl: huaweicloudsdkcce/v3/model/show_autopilot_chart_values_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowAutopilotChartValuesResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'values': 'ChartValueValues'
    }

    attribute_map = {
        'values': 'values'
    }

    def __init__(self, values=None):
        r"""ShowAutopilotChartValuesResponse

        The model defined in huaweicloud sdk

        :param values: 
        :type values: :class:`huaweicloudsdkcce.v3.ChartValueValues`
        """
        
        super(ShowAutopilotChartValuesResponse, self).__init__()

        self._values = None
        self.discriminator = None

        if values is not None:
            self.values = values

    @property
    def values(self):
        r"""Gets the values of this ShowAutopilotChartValuesResponse.

        :return: The values of this ShowAutopilotChartValuesResponse.
        :rtype: :class:`huaweicloudsdkcce.v3.ChartValueValues`
        """
        return self._values

    @values.setter
    def values(self, values):
        r"""Sets the values of this ShowAutopilotChartValuesResponse.

        :param values: The values of this ShowAutopilotChartValuesResponse.
        :type values: :class:`huaweicloudsdkcce.v3.ChartValueValues`
        """
        self._values = values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowAutopilotChartValuesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
